﻿param($installPath, $toolsPath, $package, $project)

$analyzersDir = Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers"
if (-Not (Test-Path $analyzersDir))
{
    return
}

$analyzersPaths = Join-Path ( $analyzersDir ) * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
    # Install the language agnostic analyzers.
    if (Test-Path $analyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $analyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
            }
        }
    }
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
    $languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
    $languageFolder = "vb"
}
if($languageFolder -eq "")
{
    return
}

foreach($analyzersPath in $analyzersPaths)
{
    # Install language specific analyzers.
    $languageAnalyzersPath = join-path $analyzersPath $languageFolder
    if (Test-Path $languageAnalyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $languageAnalyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
            }
        }
    }
}
# SIG # Begin signature block
# MIIorQYJKoZIhvcNAQcCoIIonjCCKJoCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCCh1voBODYpfCet
# zwmmor0XvG3ngI9/l8E/7NCzPBjyWaCCDeUwggZjMIIES6ADAgECAhMzAAADfMn2
# vO0HWa4IAAAAAAN8MA0GCSqGSIb3DQEBDAUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjMwNTExMTkwMzMyWhcNMjQwNTA4MTkwMzMyWjBjMQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQDEwQuTkVU
# MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAzvCJrwx8/B3ia0gumPyq
# gUXY1T0AZSHoozGOgfnCwqj8I0zOeXDrPpAOhcx3VKNEf+eZYsn1TAqwgcLjCNwg
# hADahMr3CIE/YLgkANySvWJvlAVUh2O3WuC+3tBW5Vy7eL7u8iVOFxYFAUMKKloC
# aVAblZIt/cNslm4vkU07mHGPDmaq1mD9GJ9SEy7qDD9lqd0k1wLdNbdmQulaGMp0
# kgmHqiZz5FhNAHIHddS3g/XBOHgCHbAiabAOdAyIdiAuIpNo/VNAFNuYHWjiKazi
# SdUux+tcqFFS6bG2gEg39jK+HCkm5eolZOBSrXdjKrE0TI0LVBa0alxbD6NKRfax
# frI2TEp7GvUP7aXK7kLic0cSjHSG4NdyfgJ4SkRGCRUCfGE8sHrw0uqrMFruQu/l
# Xxw2X2sbYUTrgAZAD1bE01SIi34i0lSCrUgXa3u10ka+awkOPTvJXRNOhTrmSpR7
# GCktoOhmLOxXhmE9iNYem/QPqO6+cE9O3iKicNycWy/3AgMBAAGjggFzMIIBbzAf
# BgNVHSUEGDAWBgorBgEEAYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQUUqlqYUdI
# RlxDIh53GnkA2wEwPkkwRQYDVR0RBD4wPKQ6MDgxHjAcBgNVBAsTFU1pY3Jvc29m
# dCBDb3Jwb3JhdGlvbjEWMBQGA1UEBRMNNDY0MjIzKzUwMTAxNTAfBgNVHSMEGDAW
# gBRIbmTlUAXTgqoXNzcitW2oynUClTBUBgNVHR8ETTBLMEmgR6BFhkNodHRwOi8v
# d3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0EyMDExXzIw
# MTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUwUzBRBggrBgEFBQcwAoZFaHR0cDov
# L3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0EyMDEx
# XzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQEMBQADggIB
# AA5IRhzUa2Q4e5oQ403ZmEbAF9VU6Wz3WlX23FW8p0nCXxeMzdQPzQ3Rzia+hVPo
# rVrxWAmibnx6Dtzoe7A+x2+E2VqyU6FecVMcZSon76Bc8OAflrbDmPQgdObJiRK/
# g0NKL27YW2BZGOV/JqD2vyS8FFS/8zwhI7Z2qd4uJCElxMv3mYVym3sl/ab5vbnA
# zpLkE+9XiyB6lkxDAYkcEA2D7DZhR+BDjfSadkeDvSIjpX6swRw9bqMVp/0H/n6+
# 9eXDjJpuvfZbeh+Szg7FNfwdV9Es7y4r+N0I4Nfa8Bpl6Htg121Maoyw6Ejoo5b4
# gBCtSe8RuJE+Y+q+AWMAfR41Sv/PL9e3yDEGtqcVB0zWBW/ntpT8cy0rwvy2kBPR
# mNyH/jETagelV1wg/GMhKUdAkgvs20QjT9Y80Dtp8SJSPwJm3GD2K/LL+Et36LgI
# 5+EV6tpazGTAz6gopilYkkVBOAlnyQeGg5NXGjEyx4R9RqXOgvQL4wewN2wyflVD
# DcsK6iqmeEbq+c3RMw2xs3J0F+VwGUAI4/P5LpA1+nravQlhZfAFu1Ez7cD10e0P
# ieqv9mO0IAbwZ3FTbbQPbjQGZTn9NlE4cfA8uXgB+aSL+6iAa+cXJ3X3AUccbzSA
# Hk32ux0pSzGE74KpTO5B66tMsrN/qUrKM5/BhDYgyk3XMIIHejCCBWKgAwIBAgIK
# YQ6Q0gAAAAAAAzANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNV
# BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
# c29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlm
# aWNhdGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1OTA5WhcNMjYwNzA4MjEw
# OTA5WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
# BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYD
# VQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAyMDExMIICIjANBgkqhkiG
# 9w0BAQEFAAOCAg8AMIICCgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGfQhsqa+la
# UKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDIOdUBFDFC04kNeWSHfpRgJGyvnkmc
# 6Whe0t+bU7IKLMOv2akrrnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13YxC4D
# dato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT+OPeBw3VXHmlSSnnDb6gE3e+
# lD3v++MrWhAfTVYoonpy4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nk
# kDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXDOW5kf1O6nA+tGSOEy/S6
# A4aN91/w0FK/jJSHvMAhdCVfGCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmd
# X4jiJV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA4bysAoJf28AVs70b1FVL
# 5zmhD+kjSbwYuER8ReTBw3J64HLnJN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zd
# sGbiwZeBe+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ecXL93KCjx7W3DKI8sj0A3
# T8HhhUSJxAlMxdSlQy90lfdu+HggWCwTXWCVmj5PM4TasIgX3p5O9JawvEagbJjS
# 4NaIjAsCAwEAAaOCAe0wggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1UdDgQWBBRI
# bmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTAL
# BgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToCMZBD
# uRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBLhklodHRwOi8vY3JsLm1pY3Jv
# c29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
# MDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEFBQcwAoZCaHR0cDovL3d3
# dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
# MDNfMjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQBgjcuAzCBgzA/BggrBgEF
# BQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1h
# cnljcHMuaHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBnAGEAbABfAHAAbwBsAGkA
# YwB5AF8AcwB0AGEAdABlAG0AZQBuAHQALiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn
# 8oalmOBUeRou09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+vj/oCso7
# v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzSGksc8zxCi1LQsP1r4z4HLimb5j0b
# pdS1HXeUOeLpZMlEPXh6I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6VoCo/
# KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu5a8n7dDd8w6vmSiXmE0OPQvy
# CInWH8MyGOLwxS3OW560STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBp
# mLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38cbxV9Rad25UAqZaPDXVJi
# hsMdYzaXht/a8/jyFqGaJ+HNpZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYb
# BL7fQccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmAH9AAKcWxm6U/RXceNcbS
# oqKfenoi+kiVH6v7RyOA9Z74v2u3S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sL
# gOppO6/8MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF670EKsT/7qMykXcGhiJtX
# cVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJUnMTDXpQzTGCGh4wghoaAgEBMIGVMH4x
# CzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
# b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01p
# Y3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTECEzMAAAN8yfa87QdZrggAAAAA
# A3wwDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQw
# HAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEILHG
# 5OyijfDOM5bxiJFmyVasy7d752HLA4qfvHm7QzF9MEIGCisGAQQBgjcCAQwxNDAy
# oBSAEgBNAGkAYwByAG8AcwBvAGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20wDQYJKoZIhvcNAQEBBQAEggGAdL/T7gbk/FiuCa5sBKniHt3/iisXPRfTom/p
# f+hJ34dz1Qp0r0QDfYSURXf7lLlbCm04uoGlmZ0FS2RJ9Ujog7ryIVm11xtKc97n
# 2AP7KAhcGyI3Ntz7z48MYx8eZGpV5piKOjsGZS2cOCv8/aIybJJujL2ShjwxJvig
# pqPXVbXuORdClYeKa0FTu55Ab+jZ+Zp+JJCuNhhswpj+gjv/AHhIFXN9hCU7lusV
# af9eXZG3pr7zyU5XI+4mG9InpyOgyhaJ3mlb8c4CaB8qBxOU469/H9VgHD2H2eIk
# KPMSOAMuZgq8Rk/gLc0R0YZrLawztZv0m7MpQwLwlSZ05Kne7Rk1KHi6mKZ84XYQ
# X4OCnG1sy0J8GyzK+f8t1Qy9POzrCbT1briWSno/hYb9ESgjL43li3LkTsnJTvEP
# qeMdfQdnADg/Uot4M/VvNom4Xv5nBEL109avNy3P/93nz4gdAgMLFKJIW/fs5t7Q
# N0oOqpTXU9VpiLBxe/iI33eBi2x8oYIXKDCCFyQGCisGAQQBgjcDAwExghcUMIIX
# EAYJKoZIhvcNAQcCoIIXATCCFv0CAQMxDzANBglghkgBZQMEAgEFADCCAVgGCyqG
# SIb3DQEJEAEEoIIBRwSCAUMwggE/AgEBBgorBgEEAYRZCgMBMDEwDQYJYIZIAWUD
# BAIBBQAEIBwGmQQiCQN0i4E8O700rEE4WkigM3ZDcNqD+CdOlTzSAgZlgzVB2cAY
# EjIwMjQwMTIyMDg0NjM1LjgxWjAEgAIB9KCB2KSB1TCB0jELMAkGA1UEBhMCVVMx
# EzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
# FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEtMCsGA1UECxMkTWljcm9zb2Z0IElyZWxh
# bmQgT3BlcmF0aW9ucyBMaW1pdGVkMSYwJAYDVQQLEx1UaGFsZXMgVFNTIEVTTjpG
# QzQxLTRCRDQtRDIyMDElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2Vy
# dmljZaCCEXgwggcnMIIFD6ADAgECAhMzAAAB4pmZlfHc4yDrAAEAAAHiMA0GCSqG
# SIb3DQEBCwUAMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
# DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
# JjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwMB4XDTIzMTAx
# MjE5MDcyNVoXDTI1MDExMDE5MDcyNVowgdIxCzAJBgNVBAYTAlVTMRMwEQYDVQQI
# EwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3Nv
# ZnQgQ29ycG9yYXRpb24xLTArBgNVBAsTJE1pY3Jvc29mdCBJcmVsYW5kIE9wZXJh
# dGlvbnMgTGltaXRlZDEmMCQGA1UECxMdVGhhbGVzIFRTUyBFU046RkM0MS00QkQ0
# LUQyMjAxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2UwggIi
# MA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQC1Y7WYVfpBZm/HCkKYNps4rA5U
# SPe/Bm9mphr2wJgndOCVRnk3v0BszPCm0KzA6Jewwu40tNyZHKz7FovVqVcLCHJE
# UPAJF9YnQRvR4cgrKQGr37r8+eZIZe26z0Mex/fVCW7BN8DJqZiWrD1qYBdOc2Zb
# 6VkA1Cw3CGMpeZVyOB1WeTejEsVjvM8Fq+K/cZDJlF7OyAsQya+Wt/UknjwCUSMs
# 52iHNFs2ejBXE0cyyzcjwROCq1b9SxXfehTcQM8J3rUnj4PPBJkXs69k9x0xRJZ3
# iV8kGHemEO3giHO8pZVqGNNwhIPYIaK6falCnAVHxXEuFxJX9xkhEZ5cybCu7P2R
# j1OHWh09o1hqGIWtkAjppIIzpgRQqkBRcBZrD62Y+HkLM2MauHOB6j51LuIU+Gqq
# b1Gd6iDl23clONqTS/d3J9Kz005XjlLDkG4L5UXbYRQgXqcX2+p27Kd33GWjwX02
# 7V1WvJy0LjAgasn7Hm7qp28I/pR0H6iqYr6cneyglgAqI+/F1MGKstR8mJ0rU5nu
# E/byurtjvyk4X0TniR4koOOMphY/t+CHBRIT6IGirzTbE1ZuEG6qYQspJ68AcqqK
# wQix+m5ZUbSTCcJruxkXU0LCMdhzCqqYRLaUptc97nwEnT64D4bECERZB2RrooS9
# SY4+C7twmwJoWtJTqwIDAQABo4IBSTCCAUUwHQYDVR0OBBYEFESEDhHavu0HbJab
# SYgkTaV4CdoFMB8GA1UdIwQYMBaAFJ+nFV0AXmJdg/Tl0mWnG1M1GelyMF8GA1Ud
# HwRYMFYwVKBSoFCGTmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY3Js
# L01pY3Jvc29mdCUyMFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEpLmNybDBsBggr
# BgEFBQcBAQRgMF4wXAYIKwYBBQUHMAKGUGh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
# bS9wa2lvcHMvY2VydHMvTWljcm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIw
# MTAoMSkuY3J0MAwGA1UdEwEB/wQCMAAwFgYDVR0lAQH/BAwwCgYIKwYBBQUHAwgw
# DgYDVR0PAQH/BAQDAgeAMA0GCSqGSIb3DQEBCwUAA4ICAQDkVEQxq1UU257pX7IN
# nE7Msoe2F74VVOzWTJCEwEGLBRD1YL0r4gspa+Wqd5Gu+mM9Lf+pcbnMyOsO7V6v
# J+FsVFIHI+cAIZzaK4Zw/JY2Km3JN+34IGCt/sBMC4T9Txgubb1ytMWKJlNZ1PpV
# zsvWUZ0oSPx2XRa8NrK4LbG1qMPTjLgA0uZYO6JK12tnWgjhp8bmg9SDvuuRO6r9
# jtFtLBo+wFnTozXaXsT67KS9ihHDjHiVZpJPztIGp4Rc8xwJ1o7TVp3lNdVkOgcb
# /DqTdX2PcM0KIsnILzjiTPd6HeeRBnl8XxfG6Hy1ZVBN8yIpKEnnfvLOtTQz/sfU
# TMmtpsCv2LNcXbw5WUx53SCrLH5rt77v2vgRX9riKMnFU7wUKb/3a0SQ+vHqONNZ
# pAkRZJsv/gZkJUa8dq2qagLuZNDXr/olHQVCpl/4jmime+b7kIO4QogQOcSJuWSF
# w0pV+O8MBWq9/wYE8J7TKva2ukEQHkv6P7mFpJr6rxPAKt/EJioE4gZ1kkv7lT3G
# hxMgK58hYeRvqnghpi+ODHxJxRIcXN7Gj5l4XujIUoAiBiVGQwO99+p0A/H5+Muu
# d+C3pfi7k+ReWxbdJi8Hfh+RsRszm2Zpv3N6RFrR79boO3Uvw363HdbJ9hOIJOFt
# S9Y3UQWyvccJDJsGPgh2XjErwTCCB3EwggVZoAMCAQICEzMAAAAVxedrngKbSZkA
# AAAAABUwDQYJKoZIhvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpX
# YXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQg
# Q29ycG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRpZmljYXRl
# IEF1dGhvcml0eSAyMDEwMB4XDTIxMDkzMDE4MjIyNVoXDTMwMDkzMDE4MzIyNVow
# fDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
# ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMd
# TWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwggIiMA0GCSqGSIb3DQEBAQUA
# A4ICDwAwggIKAoICAQDk4aZM57RyIQt5osvXJHm9DtWC0/3unAcH0qlsTnXIyjVX
# 9gF/bErg4r25PhdgM/9cT8dm95VTcVrifkpa/rg2Z4VGIwy1jRPPdzLAEBjoYH1q
# UoNEt6aORmsHFPPFdvWGUNzBRMhxXFExN6AKOG6N7dcP2CZTfDlhAnrEqv1yaa8d
# q6z2Nr41JmTamDu6GnszrYBbfowQHJ1S/rboYiXcag/PXfT+jlPP1uyFVk3v3byN
# pOORj7I5LFGc6XBpDco2LXCOMcg1KL3jtIckw+DJj361VI/c+gVVmG1oO5pGve2k
# rnopN6zL64NF50ZuyjLVwIYwXE8s4mKyzbnijYjklqwBSru+cakXW2dg3viSkR4d
# Pf0gz3N9QZpGdc3EXzTdEonW/aUgfX782Z5F37ZyL9t9X4C626p+Nuw2TPYrbqgS
# Uei/BQOj0XOmTTd0lBw0gg/wEPK3Rxjtp+iZfD9M269ewvPV2HM9Q07BMzlMjgK8
# QmguEOqEUUbi0b1qGFphAXPKZ6Je1yh2AuIzGHLXpyDwwvoSCtdjbwzJNmSLW6Cm
# gyFdXzB0kZSU2LlQ+QuJYfM2BjUYhEfb3BvR/bLUHMVr9lxSUV0S2yW6r1AFemzF
# ER1y7435UsSFF5PAPBXbGjfHCBUYP3irRbb1Hode2o+eFnJpxq57t7c+auIurQID
# AQABo4IB3TCCAdkwEgYJKwYBBAGCNxUBBAUCAwEAATAjBgkrBgEEAYI3FQIEFgQU
# KqdS/mTEmr6CkTxGNSnPEP8vBO4wHQYDVR0OBBYEFJ+nFV0AXmJdg/Tl0mWnG1M1
# GelyMFwGA1UdIARVMFMwUQYMKwYBBAGCN0yDfQEBMEEwPwYIKwYBBQUHAgEWM2h0
# dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvRG9jcy9SZXBvc2l0b3J5Lmh0
# bTATBgNVHSUEDDAKBggrBgEFBQcDCDAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMA
# QTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBTV9lbL
# j+iiXGJo0T2UkFvXzpoYxDBWBgNVHR8ETzBNMEugSaBHhkVodHRwOi8vY3JsLm1p
# Y3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29DZXJBdXRfMjAxMC0w
# Ni0yMy5jcmwwWgYIKwYBBQUHAQEETjBMMEoGCCsGAQUFBzAChj5odHRwOi8vd3d3
# Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIz
# LmNydDANBgkqhkiG9w0BAQsFAAOCAgEAnVV9/Cqt4SwfZwExJFvhnnJL/Klv6lwU
# tj5OR2R4sQaTlz0xM7U518JxNj/aZGx80HU5bbsPMeTCj/ts0aGUGCLu6WZnOlNN
# 3Zi6th542DYunKmCVgADsAW+iehp4LoJ7nvfam++Kctu2D9IdQHZGN5tggz1bSNU
# 5HhTdSRXud2f8449xvNo32X2pFaq95W2KFUn0CS9QKC/GbYSEhFdPSfgQJY4rPf5
# KYnDvBewVIVCs/wMnosZiefwC2qBwoEZQhlSdYo2wh3DYXMuLGt7bj8sCXgU6ZGy
# qVvfSaN0DLzskYDSPeZKPmY7T7uG+jIa2Zb0j/aRAfbOxnT99kxybxCrdTDFNLB6
# 2FD+CljdQDzHVG2dY3RILLFORy3BFARxv2T5JL5zbcqOCb2zAVdJVGTZc9d/HltE
# AY5aGZFrDZ+kKNxnGSgkujhLmm77IVRrakURR6nxt67I6IleT53S0Ex2tVdUCbFp
# AUR+fKFhbHP+CrvsQWY9af3LwUFJfn6Tvsv4O+S3Fb+0zj6lMVGEvL8CwYKiexcd
# FYmNcP7ntdAoGokLjzbaukz5m/8K6TT4JDVnK+ANuOaMmdbhIurwJ0I9JZTmdHRb
# atGePu1+oDEzfbzL6Xu/OHBE0ZDxyKs6ijoIYn/ZcGNTTY3ugm2lBRDBcQZqELQd
# VTNYs6FwZvKhggLUMIICPQIBATCCAQChgdikgdUwgdIxCzAJBgNVBAYTAlVTMRMw
# EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
# aWNyb3NvZnQgQ29ycG9yYXRpb24xLTArBgNVBAsTJE1pY3Jvc29mdCBJcmVsYW5k
# IE9wZXJhdGlvbnMgTGltaXRlZDEmMCQGA1UECxMdVGhhbGVzIFRTUyBFU046RkM0
# MS00QkQ0LUQyMjAxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZp
# Y2WiIwoBATAHBgUrDgMCGgMVABabmWn6dG56SXSIX4gdXfKU6IZvoIGDMIGApH4w
# fDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
# ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMd
# TWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwDQYJKoZIhvcNAQEFBQACBQDp
# WIlCMCIYDzIwMjQwMTIyMTQyNzE0WhgPMjAyNDAxMjMxNDI3MTRaMHQwOgYKKwYB
# BAGEWQoEATEsMCowCgIFAOlYiUICAQAwBwIBAAICATIwBwIBAAICEUYwCgIFAOlZ
# 2sICAQAwNgYKKwYBBAGEWQoEAjEoMCYwDAYKKwYBBAGEWQoDAqAKMAgCAQACAweh
# IKEKMAgCAQACAwGGoDANBgkqhkiG9w0BAQUFAAOBgQCcpRoWE5OyzsKy7zsrdDcT
# 0awuFlv2rtpX5sOgCmnQ5+tiDwhW1AbVwT2dwjxZMRbt13G88LMT+WS/P0AGX4qi
# QVke7Ykkruj06d61/QmOkQ+rppkhnV7oEgrAMSzmSz+Wm8ASpV3XFoQvS5QPUDCD
# gwo15NGh5p2o74s4/E/EfDGCBA0wggQJAgEBMIGTMHwxCzAJBgNVBAYTAlVTMRMw
# EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
# aWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0
# YW1wIFBDQSAyMDEwAhMzAAAB4pmZlfHc4yDrAAEAAAHiMA0GCWCGSAFlAwQCAQUA
# oIIBSjAaBgkqhkiG9w0BCQMxDQYLKoZIhvcNAQkQAQQwLwYJKoZIhvcNAQkEMSIE
# IOXjeSFD/Rjqqog6h0wHOQV62wjNn5F0esmrLsoTDMXGMIH6BgsqhkiG9w0BCRAC
# LzGB6jCB5zCB5DCBvQQgK4kqShD9JrjGwVBEzg6C+HeS1OiP247nCGZDiQiPf/8w
# gZgwgYCkfjB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
# A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYw
# JAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMAITMwAAAeKZmZXx
# 3OMg6wABAAAB4jAiBCC1x2ZsvGX+EwIutmQ1DLc8nInOYfyKFv0wf3h1pbRFZTAN
# BgkqhkiG9w0BAQsFAASCAgAg4R/e1sLhdoopUood1/PfePNOh3KQ8l0TVAEa1iRf
# HCH71LpyKhQ0gNqUTflkYjw1qieVWnbKpW9RVqQWelpBGsLX6Y3lxG56ZR5ZKRZm
# TSm5vzRV85/qQlSsfICGvRriCS/Xwhzh0t3s1kodRdDcrNaBF+J6gfdKEAQ0Sh0K
# 0t9zDT2u1SPlgAataqI6pO0g7DGQ/aSqAuj8Ypb3RQ8KRWENj3tzqayveTIZT+8I
# VySSVD5q0psLiYxytAOeu90ki17QwUGY+ldWseK7XIt4NGI2Wi1Ood+VdGs0tQZb
# ajbAaUgG4+PB19thMwEk099xsyVMKrp8aqiRdcCPt3WJAbc94JIVHcKy5onEkdUX
# zeXzwi2nLan8dJrZ8UpyO0+4mN/5vF92Y9L4Os39mNmKRBuemXsZa91uyIPmKJeS
# 9J0dJUz7/PVBEFdxqjWgq24cijM1y0l70I/4C8tUXDleRaWkuYKzv8tUFmXss8Ls
# 5J671LyOjPFBZ8QoShi0PAr+xeFMWw5EEoujEmjliA6CX5xHhXfEOJA3wLVSoify
# dF+t+kWjPmmNo3rhqH7WVqtmPPR1/ahQetBhtxUQAwd/Eu5cD0C/nJFphONhNz5B
# aTckYYejf2BPiHksO+/RAisq4N3mSqaAqV5hVb1cOCYZdwwX+gCP2Q9FkueQilm6
# yQ==
# SIG # End signature block
